/*------------------------------------------------------------------------
 *
 * ave_iir.c -- averaging filter based on IIR
 *
 *------------------------------------------------------------------------
 */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

int     n;
#define MAXLEN	1000
#define MAXFLD	10

#define WINLEN	20

int	time;
double	sample;
double	x[WINLEN], y[WINLEN];
double	sum;
double	average;

int     main(argc,argv)
int     argc;
char    **argv;
{
	int	N, i, fieldnum, indexnum, maxfieldnum;
	char	s[MAXLEN], u[MAXLEN];
        char    *field[MAXFLD];

	if (argc != 2) {
		fprintf(stderr,"usage: %s <window size>\n",argv[0]);
		exit(1);
	}
	N = atoi(argv[1]);

        /* initialize history
         */
	for (n = 0; n < WINLEN; n++) {
		x[n] = 0;
		y[n] = 0;
	}

        /* read and process data
         */
        n = 0;
	average = 0;
	maxfieldnum = 0;
        for (;;) {

		/* read x
		 */
                fgets(s,MAXLEN,stdin);
                if (feof(stdin))
                        break;

		s[strlen(s)-1] = '\0';
		strcpy(u,s);
		fieldnum = getargs(u,field);

		if (fieldnum != 2) {
			fprintf(stderr,"must have 2 fields\n");
			exit(-1);
		}
		// printf("%s %s\n",field[0],field[1]);
		time = atoi(field[0]);
		sample = atof(field[1]);

		/* update sample history
		 */
		for (i = WINLEN-1; i > 0; i--) {
			x[i] = x[i-1];
			y[i] = y[i-1];
		}
		x[0] = sample;


		/* Actual filter section:
		 * ======================
		 *
		 * averaging filter with N cells using IIR
		 */
		sum = (N-1) * y[1] + x[0];
		y[0] = sum / N;


		/* write y
		 */
		printf("%d %f\n",time,y[0]);

                n++;
        }
	fprintf(stderr,"%d samples processed\n",n);
        fclose(stdin);
}


/*----------------------------------------------------------------
 * getargs -- parse command line in argc / argv format
 *----------------------------------------------------------------
 */
int             getargs(cmd,argv)
char            *cmd,*argv[];
{
        int             argc;
        int             c,l;

        l = strlen(cmd);
        c = 0;
        for (argc = 0; c < l; argc++) {
                while (c < l && (cmd[c] == ' ' || cmd[c] == '\t'))
                        c++;
                if (c == l)
                        break;
                argv[argc] = &(cmd[c]);
                while (c < l && (cmd[c] != ' ' && cmd[c] != '\t'))
                        c++;
                cmd[c] = '\0';
                c++;
        }
        return argc;
}

